@@ -13,8 +13,8 @@ use Carp qw/croak/;
 has 'owner' => ( isa => 'Str', is => 'ro', required => 1 );
 
 # login
-has 'login'  => ( is => 'ro', isa => 'Str', default => '' );
-has 'token' => ( is => 'ro', isa => 'Str', default => '' );
+has 'login' => (is => 'rw', isa => 'Str', predicate => 'has_login',);
+has 'token' => (is => 'rw', isa => 'Str', predicate => 'has_token',);
 
 # api
 has 'api_url' => ( is => 'ro', default => 'http://github.com/api/v2/json/');
@@ -27,7 +27,7 @@ has 'ua' => (
     default => sub {
         my $self = shift;
         my $m    = WWW::Mechanize::GZip->new(
-			agent       => "perl-net-github $VERSION",
+            agent       => "perl-net-github $VERSION",
             cookie_jar  => {},
             stack_depth => 1,
             keep_alive  => 4,
@@ -39,7 +39,7 @@ has 'ua' => (
 
 sub get {
     my $self = shift;
-    
+
     my $resp = $self->ua->get(@_);
     croak $resp->as_string() unless ( $resp->is_success );
     return $resp->content();
@@ -56,7 +56,7 @@ has 'json' => (
 
 sub get_json_to_obj {
     my ( $self, $pending_url, $key ) = @_;
-    
+
     $pending_url =~ s!^/!!; # Strip leading '/'
     my $url  = $self->api_url . $pending_url;
     my $resp = $self->ua->get($url);
@@ -64,17 +64,35 @@ sub get_json_to_obj {
     return { error => $resp->as_string() } unless ( $resp->is_success );
     my $json = $resp->content();
     my $data = $self->json->jsonToObj($json);
-    
+
     return $data->{$key} if ( $key and exists $data->{$key} );
     return $data;
 }
 
+before get_json_to_obj_authed => sub {
+    my $self = shift;
+
+    return if $self->has_login and $self->has_token;
+
+    eval { require Config::GitLike::Git; };
+    return if $@;
+
+    my $c = Config::GitLike::Git->new();
+    $c->load;
+    my $login = $c->get(key => 'github.user');
+    my $token = $c->get(key => 'github.token');
+    if ($login && $token) {
+        $self->login($login);
+        $self->token($token);
+    }
+};
+
 sub get_json_to_obj_authed {
     my $self = shift;
     my $pending_url = shift;
-    
-    croak 'login and token are required' unless ( $self->login and $self->token );
-    
+
+    croak 'login and token are required' unless ( $self->has_login and $self->has_token );
+
     $pending_url =~ s!^/!!; # Strip leading '/'
     my $url  = ( $pending_url =~ /^https?\:/ ) ? $pending_url :
         $self->api_url . $pending_url;
@@ -83,7 +101,7 @@ sub get_json_to_obj_authed {
     if ( scalar @_ % 2 ) {
         $key = pop @_;
     }
-    
+
     require HTTP::Request::Common;
     my $res = $self->ua->request(
         HTTP::Request::Common::POST( $url, [
@@ -94,10 +112,10 @@ sub get_json_to_obj_authed {
     );
     return { error => '404 Not Found' } if $res->code == 404;
     return { error => $res->as_string() } unless ( $res->is_success );
-    
+
     my $json = $res->content();
     my $data = $self->json->jsonToObj($json);
-    
+
     return $data->{$key} if ( $key and exists $data->{$key} );
     return $data;
 }
@@ -118,17 +136,19 @@ __END__
 
 =head1 NAME
 
-Net::GitHub::V2::NoRepo - Base role for Net::GitHub::V2, no repo access 
+Net::GitHub::V2::NoRepo - Base role for Net::GitHub::V2, no repo access
 
 =head1 SYNOPSIS
 
     package Net::GitHub::V2::XXX;
-    
+
     use Any::Moose;
     with 'Net::GitHub::V2::NoRepo';
 
 =head1 DESCRIPTION
 
+If login and token are not given to new, the module will look in the B<.gitconfig> file if they are defined (see L<http://github.com/blog/180-local-github-config>).
+
 =head1 ATTRIBUTES
 
 =over 4
