@@ -1,6 +1,6 @@
 package Net::GitHub::V2::Users;
 
-use Moose;
+use Any::Moose;
 
 our $VERSION = '0.17';
 our $AUTHORITY = 'cpan:FAYLAND';
@@ -108,7 +108,7 @@ sub list {
     return $self->get_json_to_obj( "repos/show/$owner", 'repositories' );
 }
 
-no Moose;
+no Any::Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
